Skip to content

Instantly share code, notes, and snippets.

@dunn
Created August 6, 2016 17:49
Show Gist options
  • Save dunn/86c9364c009a9ba99243da653aecbd23 to your computer and use it in GitHub Desktop.
Save dunn/86c9364c009a9ba99243da653aecbd23 to your computer and use it in GitHub Desktop.
From 15b1b8ebbb21499470154b5ba977b646a5a7fd38 Mon Sep 17 00:00:00 2001
From: Alex Dunn <[email protected]>
Date: Sat, 6 Aug 2016 10:48:28 -0700
Subject: [PATCH] Revert "Disable multicolor fonts on OS X since they are not
supported on free systems"
This reverts commit 9344612d3cd164317170b6189ec43175757e4231.
---
src/macfont.m | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/src/macfont.m b/src/macfont.m
index 0445628..c9082a5 100644
--- a/src/macfont.m
+++ b/src/macfont.m
@@ -2373,9 +2373,9 @@ macfont_list (struct frame *f, Lisp_Object spec)
!= (spacing >= FONT_SPACING_MONO)))
continue;
- /* Don't use a color bitmap font until it is supported on
- free platforms. */
- if (sym_traits & kCTFontTraitColorGlyphs)
+ /* Don't use a color bitmap font unless its family is
+ explicitly specified. */
+ if ((sym_traits & kCTFontTraitColorGlyphs) && NILP (family))
continue;
if (j > 0
--
2.9.2
Sign up for free to join this conversation on GitHub. Already have an account? Sign in to comment